Documentation
¶
Index ¶
Constants ¶
const ( OptimizedFor = "develop" Name = "Vega Wallet Dev" )
Variables ¶
var ( // VersionHash specifies the git commit used to build the application. // See VERSION_HASH in Makefile for details. VersionHash = "unknown" // Version specifies the version used to build the application. // See VERSION in Makefile for details. Version = "v0.15.0" About = fmt.Sprintf(aboutAppTemplate, Version, VersionHash) )
var ErrLogLevelIsRequired = errors.New("the log level is required")
Functions ¶
func StartupLogFilePath ¶
Types ¶
type AppFilesLocation ¶
type Config ¶
type Config struct {
LogLevel string `json:"logLevel"`
VegaHome string `json:"vegaHome"`
DefaultNetwork string `json:"defaultNetwork"`
Telemetry TelemetryConfig `json:"telemetry"`
}
func (*Config) EnsureIsValid ¶
type ConfigLoader ¶
type ConfigLoader struct {
// contains filtered or unexported fields
}
func NewConfigLoader ¶
func NewConfigLoader() (*ConfigLoader, error)
func (*ConfigLoader) GetConfig ¶
func (l *ConfigLoader) GetConfig() (Config, error)
func (*ConfigLoader) IsConfigInitialised ¶
func (l *ConfigLoader) IsConfigInitialised() (bool, error)
func (*ConfigLoader) MarkOnBoardingAsDone ¶
func (l *ConfigLoader) MarkOnBoardingAsDone() error
func (*ConfigLoader) SaveConfig ¶
func (l *ConfigLoader) SaveConfig(config Config) error
type FilesLocation ¶
type FilesLocation struct {
AppFiles AppFilesLocation `json:"appFiles"`
HomeFiles HomeFilesLocation `json:"homeFiles"`
}
type HomeFilesLocation ¶
type TelemetryConfig ¶
type TelemetryConfig struct {
// ConsentAsked is used to determine if the user has been asked for his
// consent for telemetry collection.
ConsentAsked bool `json:"consentAsked"`
// Enabled is used to enable or disable the collection of errors on the
// software.
Enabled bool `json:"enabled"`
}
TelemetryConfig is used to configure the telemetry collection on the client.
Click to show internal directories.
Click to hide internal directories.